This crate provides a data driver implementation for dusk stake contract.
Structs
- Contract
Driver - The contract driver for encoding and decoding transactions.
This crate provides a data driver implementation for dusk stake contract.